from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Video = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AD725', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD725'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'Video', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD725.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nAD725\n\nVideo', 'pins':[
            Pin(num='1',name='NTSC/PAL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CVBS_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='LUM_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='TRAP',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VSYNC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='HSYNC',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='4FSC_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CE',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RED',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GREEN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='BLUE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CHROM_OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9708AR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9708AR'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'DAC CNA VIDEO', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD9708.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nAD9708AR\n\nDAC CNA VIDEO', 'pins':[
            Pin(num='1',name='DB7',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SLEEP',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='REFLO',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='REFIO',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='FS_ADJ',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='COMP1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DB6',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ACOM',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='IOUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='IOUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='COMP2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='DCOM',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='Clock',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DB5',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DB4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DB3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DB2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DB1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DB0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9891', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9891'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-64_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:BGA-64_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'CCD Signal Processor', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/AD9891_9895.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nAD9891\n\nCCD Signal Processor', 'pins':[
            Pin(num='A1',name='VD',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='AVDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='MSHUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='A4',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='REFT',func=pin_types.OUTPUT,unit=1),
            Pin(num='A6',name='REFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='A7',name='BYP3',func=pin_types.OUTPUT,unit=1),
            Pin(num='A8',name='CDD-IN',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='BYP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='B1',name='HD',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='TCVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='STROBE',func=pin_types.OUTPUT,unit=1),
            Pin(num='B4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='SL',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='B7',name='AVDD2',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='BYP2',func=pin_types.OUTPUT,unit=1),
            Pin(num='B9',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='CLI',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='LD/FD',func=pin_types.OUTPUT,unit=1),
            Pin(num='C9',name='TCVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='DCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='D10',name='CLO',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='PBLK/CLPOB',func=pin_types.OUTPUT,unit=1),
            Pin(num='D9',name='RG',func=pin_types.OUTPUT,unit=1),
            Pin(num='E10',name='RGVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='RGVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='F10',name='H3',func=pin_types.OUTPUT,unit=1),
            Pin(num='F2',name='D0/SD0',func=pin_types.OUTPUT,unit=1),
            Pin(num='F9',name='H4',func=pin_types.OUTPUT,unit=1),
            Pin(num='G1',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='G10',name='HVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='G9',name='HVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='H10',name='H1',func=pin_types.OUTPUT,unit=1),
            Pin(num='H2',name='D4',func=pin_types.OUTPUT,unit=1),
            Pin(num='H9',name='H2',func=pin_types.OUTPUT,unit=1),
            Pin(num='J1',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='J10',name='VSG8',func=pin_types.OUTPUT,unit=1),
            Pin(num='J2',name='D6',func=pin_types.OUTPUT,unit=1),
            Pin(num='J3',name='VSUB',func=pin_types.OUTPUT,unit=1),
            Pin(num='J4',name='SUBCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='J5',name='V2',func=pin_types.OUTPUT,unit=1),
            Pin(num='J6',name='V4',func=pin_types.OUTPUT,unit=1),
            Pin(num='J7',name='VSG2/V6',func=pin_types.OUTPUT,unit=1),
            Pin(num='J8',name='VSG4/V8',func=pin_types.OUTPUT,unit=1),
            Pin(num='J9',name='VSG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='K1',name='D9',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSG7',func=pin_types.OUTPUT,unit=1),
            Pin(num='K2',name='D8',func=pin_types.OUTPUT,unit=1),
            Pin(num='K3',name='DRVDD',func=pin_types.PWROUT,unit=1),
            Pin(num='K4',name='DRVSS',func=pin_types.PWROUT,unit=1),
            Pin(num='K5',name='V1',func=pin_types.OUTPUT,unit=1),
            Pin(num='K6',name='V3',func=pin_types.OUTPUT,unit=1),
            Pin(num='K7',name='VSG1/V5',func=pin_types.OUTPUT,unit=1),
            Pin(num='K8',name='VSG3/V7',func=pin_types.OUTPUT,unit=1),
            Pin(num='K9',name='VSG5',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9895', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9895'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-64_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:BGA-64_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'CCD Signal Processor', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/AD9891_9895.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nAD9895\n\nCCD Signal Processor', 'pins':[
            Pin(num='A1',name='VD',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='AVDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='MSHUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='A4',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='REFT',func=pin_types.OUTPUT,unit=1),
            Pin(num='A6',name='REFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='A7',name='BYP3',func=pin_types.OUTPUT,unit=1),
            Pin(num='A8',name='CDD-IN',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='BYP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='B1',name='HD',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='TCVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='STROBE',func=pin_types.OUTPUT,unit=1),
            Pin(num='B4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='SL',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='B7',name='AVDD2',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='BYP2',func=pin_types.OUTPUT,unit=1),
            Pin(num='B9',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='CLI',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='LD/FD',func=pin_types.OUTPUT,unit=1),
            Pin(num='C9',name='TCVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='DCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='D10',name='CLO',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='PBLK/CLPOB',func=pin_types.OUTPUT,unit=1),
            Pin(num='D9',name='RG',func=pin_types.OUTPUT,unit=1),
            Pin(num='E1',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='E10',name='RGVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='D0',func=pin_types.OUTPUT,unit=1),
            Pin(num='E9',name='RGVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='F10',name='H3',func=pin_types.OUTPUT,unit=1),
            Pin(num='F2',name='D2/SD0',func=pin_types.OUTPUT,unit=1),
            Pin(num='F9',name='H4',func=pin_types.OUTPUT,unit=1),
            Pin(num='G1',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='G10',name='HVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='D4',func=pin_types.OUTPUT,unit=1),
            Pin(num='G9',name='HVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='H10',name='H1',func=pin_types.OUTPUT,unit=1),
            Pin(num='H2',name='D6',func=pin_types.OUTPUT,unit=1),
            Pin(num='H9',name='H2',func=pin_types.OUTPUT,unit=1),
            Pin(num='J1',name='D9',func=pin_types.OUTPUT,unit=1),
            Pin(num='J10',name='VSG8',func=pin_types.OUTPUT,unit=1),
            Pin(num='J2',name='D8',func=pin_types.OUTPUT,unit=1),
            Pin(num='J3',name='VSUB',func=pin_types.OUTPUT,unit=1),
            Pin(num='J4',name='SUBCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='J5',name='V2',func=pin_types.OUTPUT,unit=1),
            Pin(num='J6',name='V4',func=pin_types.OUTPUT,unit=1),
            Pin(num='J7',name='VSG2/V6',func=pin_types.OUTPUT,unit=1),
            Pin(num='J8',name='VSG4/V8',func=pin_types.OUTPUT,unit=1),
            Pin(num='J9',name='VSG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='K1',name='D11',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSG7',func=pin_types.OUTPUT,unit=1),
            Pin(num='K2',name='D10',func=pin_types.OUTPUT,unit=1),
            Pin(num='K3',name='DRVDD',func=pin_types.PWROUT,unit=1),
            Pin(num='K4',name='DRVSS',func=pin_types.PWROUT,unit=1),
            Pin(num='K5',name='V1',func=pin_types.OUTPUT,unit=1),
            Pin(num='K6',name='V3',func=pin_types.OUTPUT,unit=1),
            Pin(num='K7',name='VSG1/V5',func=pin_types.OUTPUT,unit=1),
            Pin(num='K8',name='VSG3/V7',func=pin_types.OUTPUT,unit=1),
            Pin(num='K9',name='VSG5',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9984AKST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9984AKST'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_14x14mm_P0.65mm'], 'footprint':'Package_QFP:LQFP-80_14x14mm_P0.65mm', 'keywords':'10bit video display interface', 'description':'', 'datasheet':'http://www.analog.com/media/en/technical-documentation/data-sheets/AD9984A.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nAD9984AKST\n\n10bit video display interface', 'pins':[
            Pin(num='1',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='G_AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='SOGIN1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VD',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='R_AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='R_AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='PWR_DN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='REF_LO',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='B_AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='REF_HI',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='O/E_FIELD',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='VSOUT/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='HSOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='SOGOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='DATACK',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='RED_9',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='RED_8',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='RED_7',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='RED_6',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='RED_5',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='RED_4',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='RED_3',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='RED_2',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='RED_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='RED_0',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='B_AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='DAV_DD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='GREEN_9',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='GREEN_8',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='GREEN_7',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='GREEN_6',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='GREEN_5',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='GREEN_4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='GREEN_3',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='GREEN_2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VD',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GREEN_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='GREEN_0',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='BLUE_9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='BLUE_8',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='BLUE_7',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='BLUE_6',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='BLUE_5',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='BLUE_4',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='G_AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='BLUE_3',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='BLUE_2',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='BLUE_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='63',name='BLUE_0',func=pin_types.OUTPUT,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='68',name='HSYNC1',func=pin_types.INPUT,unit=1),
            Pin(num='69',name='VSYNC1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='HSYNC0',func=pin_types.INPUT,unit=1),
            Pin(num='71',name='VSYNC0',func=pin_types.INPUT,unit=1),
            Pin(num='72',name='EXTCK/COAST',func=pin_types.INPUT,unit=1),
            Pin(num='73',name='CLAMP',func=pin_types.INPUT,unit=1),
            Pin(num='74',name='PV_D',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='PV_D',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='FILT',func=pin_types.INPUT,unit=1),
            Pin(num='79',name='PV_D',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SOGIN0',func=pin_types.INPUT,unit=1),
            Pin(num='80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADA4430-1YKSZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADA4430-1YKSZ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'Video Filter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADA4430-1.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nADA4430-1YKSZ\n\nVideo Filter', 'pins':[
            Pin(num='1',name='V_{IN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SAG',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V_{OUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{DIS}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{S}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADV7280xCP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADV7280xCP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm'], 'footprint':'Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm', 'keywords':'video decoder', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADV7280.PDF', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nADV7280xCP\n\nvideo decoder', 'pins':[
            Pin(num='1',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='P1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='P0',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='XTALP',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='XTALN',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='VREFP',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='DVDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='VREFN',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~INTRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='~RESET',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='ALSB',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VS/FIELD/SFL',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='HS',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='~PWRDWN',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='LLC',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P7',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='P6',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='P5',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='P4',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='P3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADV7390BCPZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADV7390BCPZ'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'Video Encoder', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADV7390_7391_7392_7393.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nADV7390BCPZ\n\nVideo Encoder', 'pins':[
            Pin(num='1',name='V_{DD_IO}',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='ALSB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='EXT_LF',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P_{VDD}',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='V_{AA}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DAC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='DAC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='DAC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='COMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='R_{SET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SFL',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{VSYNC}',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='~{HSYNC}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='V_{DD}',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='GND_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='P7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AV9173', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AV9173'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'video pll', 'description':'', 'datasheet':'http://www.ibselectronics.com/ibsstore/datasheet/Others/AV9173-01CN08.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nAV9173\n\nvideo pll', 'pins':[
            Pin(num='1',name='FSIGIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='FREFIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='FS0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CKKOUT',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='VCC',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CLK/2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CX7930', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CX7930'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nCX7930\n\n', 'pins':[
            Pin(num='1',name='VRI',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='4FSCI',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='OVD',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VSS',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='LALTRI',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='OSC',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OFLD1',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='EXT',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='MODE1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='MODE2',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='HRI',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='HCOMO',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='CLOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='CLIN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OFH',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='OBF',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='OSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='OFLD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OBLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OLALT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OHD',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='4FSCO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CXD3400N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CXD3400N'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'CCD Clock Driver', 'description':'', 'datasheet':'video\\cxd3400n.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nCXD3400N\n\nCCD Clock Driver', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='XV2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='V2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='V4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='V1A',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VH',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='V1B',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='V3A',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VL',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='V3B',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='XSHT',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='XV3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='XSG3B',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XSG3A',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XV1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XSG1B',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XSG1A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='XV4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HD63484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HD63484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nHD63484\n\n', 'pins':[
            Pin(num='1',name='CUD1',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='DTACK',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='IRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='HSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='EXTSYNC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='CUD2',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='24',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='25',name='D8',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='D9',func=pin_types.TRISTATE,unit=1),
            Pin(num='27',name='D10',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='D11',func=pin_types.TRISTATE,unit=1),
            Pin(num='29',name='D12',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='R/W',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D13',func=pin_types.TRISTATE,unit=1),
            Pin(num='31',name='D14',func=pin_types.TRISTATE,unit=1),
            Pin(num='32',name='D15',func=pin_types.TRISTATE,unit=1),
            Pin(num='33',name='RA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='MA19/RA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='MA18/RA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='MA17/RA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='MA16/RA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='MAD15',func=pin_types.TRISTATE,unit=1),
            Pin(num='39',name='MAD14',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='MAD13',func=pin_types.TRISTATE,unit=1),
            Pin(num='41',name='MAD12',func=pin_types.TRISTATE,unit=1),
            Pin(num='42',name='MAD11',func=pin_types.TRISTATE,unit=1),
            Pin(num='43',name='MAD10',func=pin_types.TRISTATE,unit=1),
            Pin(num='44',name='MAD9',func=pin_types.TRISTATE,unit=1),
            Pin(num='45',name='MAD8',func=pin_types.TRISTATE,unit=1),
            Pin(num='46',name='MAD7',func=pin_types.TRISTATE,unit=1),
            Pin(num='47',name='MAD6',func=pin_types.TRISTATE,unit=1),
            Pin(num='48',name='MAD5',func=pin_types.TRISTATE,unit=1),
            Pin(num='49',name='VCC',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RS',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='2CLK',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='MCYC',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='AS',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DRAW',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='MRD',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='CHR',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='MAD4',func=pin_types.TRISTATE,unit=1),
            Pin(num='58',name='MAD3',func=pin_types.TRISTATE,unit=1),
            Pin(num='59',name='MAD2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MAD1',func=pin_types.TRISTATE,unit=1),
            Pin(num='61',name='MAD0',func=pin_types.TRISTATE,unit=1),
            Pin(num='62',name='DISP2',func=pin_types.OUTPUT,unit=1),
            Pin(num='63',name='DISP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='64',name='LPSTB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DONE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DREQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='DACK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HD63484_PLCC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HD63484_PLCC'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nHD63484_PLCC\n\n', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DACK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DTACK',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='IRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='HSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='EXTSYNC',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='CUD1',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='24',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='25',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='27',name='D8',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='D9',func=pin_types.TRISTATE,unit=1),
            Pin(num='29',name='D10',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='CUD2',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='D11',func=pin_types.TRISTATE,unit=1),
            Pin(num='31',name='D12',func=pin_types.TRISTATE,unit=1),
            Pin(num='32',name='D13',func=pin_types.TRISTATE,unit=1),
            Pin(num='33',name='D14',func=pin_types.TRISTATE,unit=1),
            Pin(num='34',name='D15',func=pin_types.TRISTATE,unit=1),
            Pin(num='35',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='MA19/RA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='MA18/RA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='MA17/RA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='R/W',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='MA16/RA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='MAD15',func=pin_types.TRISTATE,unit=1),
            Pin(num='42',name='MAD14',func=pin_types.TRISTATE,unit=1),
            Pin(num='43',name='MAD13',func=pin_types.TRISTATE,unit=1),
            Pin(num='44',name='MAD12',func=pin_types.TRISTATE,unit=1),
            Pin(num='45',name='MAD11',func=pin_types.TRISTATE,unit=1),
            Pin(num='46',name='MAD10',func=pin_types.TRISTATE,unit=1),
            Pin(num='47',name='MAD9',func=pin_types.TRISTATE,unit=1),
            Pin(num='48',name='MAD8',func=pin_types.TRISTATE,unit=1),
            Pin(num='49',name='MAD7',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='MAD6',func=pin_types.TRISTATE,unit=1),
            Pin(num='51',name='MAD5',func=pin_types.TRISTATE,unit=1),
            Pin(num='52',name='VCC',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='2CLK',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='MCYC',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='AS',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='DRAW',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='MRD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='RS',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='CHR',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='MAD4',func=pin_types.TRISTATE,unit=1),
            Pin(num='62',name='MAD3',func=pin_types.TRISTATE,unit=1),
            Pin(num='63',name='MAD2',func=pin_types.TRISTATE,unit=1),
            Pin(num='64',name='MAD1',func=pin_types.TRISTATE,unit=1),
            Pin(num='65',name='MAD0',func=pin_types.TRISTATE,unit=1),
            Pin(num='66',name='DISP2',func=pin_types.OUTPUT,unit=1),
            Pin(num='67',name='DISP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='68',name='LPSTB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DONE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DREQ',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ICX415AQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ICX415AQ'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'CCD B/W Image Sensor', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nICX415AQ\n\nCCD B/W Image Sensor', 'pins':[
            Pin(num='10',name='CGG',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='RG',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VL',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='SUB',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='H1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='H2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='CSUB',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='SUBCIR',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='V3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISL59885', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISL59885'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'video sync separator csync hsync vsync', 'description':'', 'datasheet':'https://www.renesas.com/us/en/document/dst/isl59885-datasheet?r=533081', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nISL59885\n\nvideo sync separator csync hsync vsync', 'pins':[
            Pin(num='1',name='CSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CVBS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{HD}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='CSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='HSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM1881', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM1881'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nLM1881\n\n', 'pins':[
            Pin(num='1',name='CSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VIDEO',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='FRAME',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='BURST',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='INT',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='O/E',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX310', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX310'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'video rf', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX310-MAX311.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nMAX310\n\nvideo rf', 'pins':[
            Pin(num='1',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V+',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='S3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='S5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='S6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='S7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='S8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX311', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX311'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'video rf', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX310-MAX311.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nMAX311\n\nvideo rf', 'pins':[
            Pin(num='1',name='S1A',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUTB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V+',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='S2A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='S3A',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S4A',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='S1B',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='S2B',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='S3B',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='S4B',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MB88303P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MB88303P'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nMB88303P\n\n', 'pins':[
            Pin(num='1',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='X/R',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='LDI',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ADM',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DA0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DA1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DA2',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='DA3',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='DA4',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DA5',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DA6',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='DA7',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VOW',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VOB',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VSYNC',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='HSYNC',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='EX/RC',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S178', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S178'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nS178\n\n', 'pins':[
            Pin(num='1',name='+VCC',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='2.1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='2.0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VR',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SV',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='-VCC',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='H2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='V',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SH',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='2.9',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='HD',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='CLAMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='N.C',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='N.B',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='N.A',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='SUP',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='VD',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='SUP',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='2.8',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='2.7',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2.6',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='2.5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2.4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='2.3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='2.2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SAA7182', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SAA7182'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Video Encoder', 'description':'', 'datasheet':'http://rcl-radio.ru/wp-content/uploads/2014/11/SAA7182.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nSAA7182\n\nVideo Encoder', 'pins':[
            Pin(num='1',name='~RESN~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DP0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DP1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DP2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DP3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DP4',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='DP5',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='DP6',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DP7',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='TTXRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='TTX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='MP7',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='MP6',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='MP5',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='MP4',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='MP3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='MP2',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='MP1',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='MP0',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RCV1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='RCV2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SA',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='XTALI',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='CREF',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='LCC',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='CDIR',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VREFL',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VREFH',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='B',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='G',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OVL2',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='61',name='R',func=pin_types.OUTPUT,unit=1),
            Pin(num='63',name='CUR',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='68',name='CUR',func=pin_types.INPUT,unit=1),
            Pin(num='69',name='C',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OVL1',func=pin_types.INPUT,unit=1),
            Pin(num='70',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='72',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='CVBS',func=pin_types.OUTPUT,unit=1),
            Pin(num='74',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VREFH',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='VREFL',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='AP',func=pin_types.INPUT,unit=1),
            Pin(num='78',name='SP',func=pin_types.INPUT,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OVL0',func=pin_types.INPUT,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='84',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='KEY',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SI582', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SI582'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nSI582\n\n', 'pins':[
            Pin(num='1',name='OFS',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUT',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DIS',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA1950', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA1950'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTDA1950\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='NIVV',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VIDEO',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='NIVH',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='PHCMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='+12',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='C',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='R',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='PHASE',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='FLYV',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='HD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='FLYH',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SANDCASTLE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SW',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='MUTE',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='NIVSEP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CS',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA2593', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA2593'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTDA2593\n\n', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='NS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VCR',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='F',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='F',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='HD',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='FW',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SANDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VD',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VIDEO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA7260', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7260'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTDA7260\n\n', 'pins':[
            Pin(num='1',name='SI',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CD',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='G4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='POMPE2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='G3',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='G2',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='POMPE1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='G1',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='CL',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='VP+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S0',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='E-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E+',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='LIM',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='+10',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA8501', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA8501'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Video Encoder', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/TDA8501.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTDA8501\n\nVideo Encoder', 'pins':[
            Pin(num='1',name='-R.Y',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VOFF',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='C/OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='FLT',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='CVBS',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='NTSC/PAL',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='NOTCH',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='Y/OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='MCTR',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='Y+SIN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='B/ADJ',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Y+SOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OSC',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-B.Y',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='H/2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='Y',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='UOFF',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA8702', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA8702'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'DAC CNA VIDEO', 'description':'', 'datasheet':'philips/tda8702.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTDA8702\n\nDAC CNA VIDEO', 'pins':[
            Pin(num='1',name='VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DB4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DB1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DB0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~VOUT~',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='DB2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DB3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DB7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DB6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DB5',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA8772', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA8772'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Video DAC Colour 8bit', 'description':'', 'datasheet':'http://www.pa0qy.nl/pdf/TDA8772.PDF', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTDA8772\n\nVideo DAC Colour 8bit', 'pins':[
            Pin(num='1',name='R7',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='BLANK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='G7',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='G6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='G5',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='G4',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='G3',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='R6',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='G0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='CLKR',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CLKG',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='CLKB',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='B7',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='B6',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='B5',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='B4',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='R5',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='B0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VRD',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BLU',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='IRFA',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='R4',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='GRE',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='IRFB',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='RED',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='R3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='R2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='R0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA9500', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA9500'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTDA9500\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FW',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SH',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SANDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='TOPV',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEA2014', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEA2014'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Video switching circuite for TV', 'description':'', 'datasheet':'http://pdf1.alldatasheet.com/datasheet-pdf/view/123244/STMICROELECTRONICS/TEA2014.html', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTEA2014\n\nVideo switching circuite for TV', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='IVI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='2/1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SVO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='EVI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEA5115', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEA5115'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTEA5115\n\n', 'pins':[
            Pin(num='1',name='ES2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='EB1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='EFB1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='ER1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='FBOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='ROUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SYOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='ER2',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='ES1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='EV1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='EV2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SEL1/2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='BOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VSP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='EB2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='EFB2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TFP410PAP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TFP410PAP'}), 'ref_prefix':'U', 'fplist':['Package_QFP:HTQFP-64-1EP_10x10mm_P0.5mm_EP8x8mm_Mask4.4x4.4mm_ThermalVias'], 'footprint':'Package_QFP:HTQFP-64-1EP_10x10mm_P0.5mm_EP8x8mm_Mask4.4x4.4mm_ThermalVias', 'keywords':'DVI Encoder Driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tfp410.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTFP410PAP\n\nDVI Encoder Driver', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~PD',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='MSEN/PO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='DVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='ISEL/~RST',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DSEL/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='BSEL/SCL',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='TFADJ',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DE',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='TGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='TXC-',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='TXC+',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='TVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='TX0-',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='TX0+',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='TGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='TX1-',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='TX1+',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='TVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='TX2-',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='TX2+',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='TGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='DVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='RESERVED',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='DKEN',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='DATA23',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='DATA22',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DATA21',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='DATA20',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='HSYNC',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='DATA19',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='DATA18',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='DATA17',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='DATA16',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='DATA15',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='DATA14',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='DATA13',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='DATA12',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='VSYNC',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='DATA11',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='DATA10',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='DATA9',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='DATA8',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='DATA7',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='DATA6',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='IDCK-',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='IDCK+',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='DATA5',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='DATA4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CTL3/A3/DK3',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='DATA3',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='DATA2',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='DATA1',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='DATA0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CTL2/A2/DK2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CTL1/A1/DK1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='EDGE/HTPLG',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADA4430-1WYRTZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADA4430-1WYRTZ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'Video Filter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADA4430-1.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nADA4430-1WYRTZ\n\nVideo Filter', 'pins':[
            Pin(num='1',name='V_{IN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SAG',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V_{OUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{DIS}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{S}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADV7391BCPZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADV7391BCPZ'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'Video Encoder', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADV7390_7391_7392_7393.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nADV7391BCPZ\n\nVideo Encoder', 'pins':[
            Pin(num='1',name='V_{DD_IO}',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='ALSB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='EXT_LF',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P_{VDD}',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='V_{AA}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DAC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='DAC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='DAC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='COMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='R_{SET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SFL',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{VSYNC}',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='~{HSYNC}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='V_{DD}',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='GND_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='P7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA1950F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA1950F'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTDA1950F\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='NIVV',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VIDEO',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='NIVH',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='PHCMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='+12',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='C',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='R',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='PHASE',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='FLYV',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='HD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='FLYH',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SANDCASTLE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SW',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='MUTE',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='NIVSEP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CS',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA8702T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA8702T'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'DAC CNA VIDEO', 'description':'', 'datasheet':'philips/tda8702.pdf', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTDA8702T\n\nDAC CNA VIDEO', 'pins':[
            Pin(num='1',name='VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DB4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DB1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DB0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~VOUT~',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='DB2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DB3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DB7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DB6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DB5',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA9503', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA9503'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTDA9503\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FW',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SH',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SANDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='TOPV',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA9513', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA9513'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Video.kicad_sym\nTDA9513\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='FW',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SH',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SANDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='TOPV',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])